Module base

Module base 

Traits and common implementations shared by different storages.

When writing code that should deal with different storage implementations, these traits should be used as input / outputs, rather than concrete per-store types.

See Storage as an entry point to this module.

Structs

Collection
Path to a collection (an address book or a calendar) inside a storage.
CollectionChanges
Changes to a collection since a known sync state.
CreateItemOptions
Options for Storage::create_item.
FetchedItem
Item fetched from a storage plus its metadata.
FetchedProperty
Property and its value fetched from a storage.
Item
Immutable item which may be stored in a Storage.
ItemHash
The hash of an item. See Item::hash.
ItemVersion
Reference to a specific version of an Item inside a collection.

Enums

ItemHashError
Error returned by ItemHash::from_str.

Traits

Storage
A storage is the highest level abstraction where items can be stored. It can be a remote CalDAV account, a local filesystem, etc.