pub struct ItemSource {
pub state: ItemState,
pub data: Option<Item>,
}Expand description
Source data for copying an item onto the other side.
Fields
state: ItemStateMetadata and state for this item.
data: Option<Item>Data for this version of the item, if available.