ResolvedCollection

Struct ResolvedCollection 

pub struct ResolvedCollection { /* private fields */ }
Collection as resolved based on existing data.

Implementations

Source

impl ResolvedCollection

pub fn id(&self) -> Option<&CollectionId>

The id for this collection.

Is None if collection does not exist AND was declared via an href.

pub fn href(&self) -> &Href

The href for this collection.

If the collection does not exist, this is the intended href under which is must be created.