Module operation

Module operation 

Synchronisation operations.

The main type is Operation, which represents a single atomic synchronisation action.

Structs

DeleteItem
Delete item from one side.
PropertyOp
Property-level synchronisation operation.
StatusOnly
Only update status database (no storage operations).
WriteItem
Write item to the target side from the source on the opposite side.

Enums

CollectionOp
Collection-level synchronisation operation.
ItemOp
Item-level synchronisation operation.
MappingUidSource
Source of mapping UID for item operations.
Operation
Operation to be executed on a pair.
PropertyOpKind
The specific kind of property operation.
StatusWrite
Status database operation to perform after the storage write.
StorageWrite
Storage operation to perform on the target side.