pub struct WriteItem {
pub source: ItemSource,
pub target_side: Side,
pub storage_write: StorageWrite,
pub status_write: StatusWrite,
pub mapping_uid: MappingUidSource,
pub on_complete: Option<DeletionCompletionHandle>,
}Expand description
Write item to the target side from the source on the opposite side.
Fields
source: ItemSourceData from the source side (the side being read from).
target_side: SideWhich side to write to.
storage_write: StorageWritestatus_write: StatusWritemapping_uid: MappingUidSourceon_complete: Option<DeletionCompletionHandle>Optional handle to signal collection deletion barrier when this operation completes.