Synchronisation operations.
The main type is Operation, which represents a single atomic synchronisation action.
Structs
- Delete
Item - Delete item from one side.
- Property
Op - Property-level synchronisation operation.
- Status
Only - Only update status database (no storage operations).
- Write
Item - Write item to the target side from the source on the opposite side.
Enums
- Collection
Op - Collection-level synchronisation operation.
- ItemOp
- Item-level synchronisation operation.
- Mapping
UidSource - Source of mapping UID for item operations.
- Operation
- Operation to be executed on a pair.
- Property
OpKind - The specific kind of property operation.
- Status
Write - Status database operation to perform after the storage write.
- Storage
Write - Storage operation to perform on the target side.